---
name: Bug report
about: Create a report to help us improve

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:

**Expected behavior**
A clear and concise description of what you expected to happen.

**Setup (please complete the following information):**
 - OS: [e.g. iOS]
 - Python version:
 - NumPy version:
 - Cython version:
 - Wildboar version: (version or commit)

**Additional context**
Add any other context about the problem here.
